<!DOCTYPE html>
<html>
  <head>
    <title>{{ project_name }} Project</title>
    <meta name="apple-mobile-web-app-capable" content="yes">
    <link rel="manifest" href="manifest.json">
    <meta name="viewport" content="width=device-width,initial-scale=1,maximum-scale=1,minimum-scale=1,user-scalable=yes" />
    <script type="module">
      import '/static/app/js/{{ project_name }}.js';
    </script>
    <link rel="stylesheet" href="/static/app/css/{{ project_name }}.css" />
  </head>
  <body>
    <script nomodule>
      document.write("This app requires ESM support.");
    </script>
  </body>
</html>
